<?php

namespace App\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

class CombatController extends AbstractController
{
    // Route designed for testing purposes
    #[Route('/combat', name: 'app_combat')]
    public function index(): Response
    {

        $leftEmoji = '🐱';
        $rightEmoji = '🐶';
        $winner = 'left';  // or 'right'
        $loser = ($winner === 'left') ? 'right' : 'left';
    
        return $this->render('combat/index.html.twig', [
            'left_emoji' => $leftEmoji,
            'right_emoji' => $rightEmoji,
            'winner' => $winner,
            'loser' => $loser,
        ]);
    }

    private function isEmoji(string $str): bool {
        $emojiRegex = '/^\X$/u';
        return preg_match($emojiRegex, $str) === 1 && mb_strlen($str, 'UTF-8') === 1;
    }

    #[Route('/combat-{leftEmoji}-{rightEmoji}-{winner}', name: 'app_combat_with_params', requirements: ['leftEmoji' => '.+', 'rightEmoji' => '.+'])]
    public function combatWithParams(string $leftEmoji, string $rightEmoji, string $winner): Response
    // Example : /combat-🐱-🐶-left
    // or /combat-🐌_☀%EF%B8%8F-🐌_☀%EF%B8%8F-left
    {
        $loser = ($winner === 'left') ? 'right' : 'left';
        // Validate emoji
        
        if (!$this->isEmoji($leftEmoji)) {
            $leftEmoji = 'https://emojik.vercel.app/s/' . $leftEmoji;
        }
        if (!$this->isEmoji($rightEmoji)) {
            $rightEmoji = 'https://emojik.vercel.app/s/' . $rightEmoji;
        }

        return $this->render('combat/index.html.twig', [
            'left_emoji' => $leftEmoji,
            'right_emoji' => $rightEmoji,
            'winner' => $winner,
            'loser' => $loser,
        ]);
    }

}
